"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const babel_target_1 = require("./babel.target");
const PLUGIN_NAME = 'NamedLazyChunksPlugin';
/**
 * Gives names to lazy chunks (lazy routes) so their assets have recognizable names instead of just numbers.
 */
class NamedLazyChunksPlugin {
    getNameFromOrigin(chunk) {
        for (let group of chunk.groupsIterable) {
            if (!group.origins || !group.origins.length) {
                continue;
            }
            const origin = group.origins.find((origin) => !!(origin.request && origin.request.match(/\.ngfactory$/)));
            if (!origin) {
                continue;
            }
            const babelTarget = babel_target_1.BabelTarget.findTarget(origin.module);
            if (!babelTarget) {
                throw new Error('no babel target for lazy chunk');
            }
            const cleanedName = origin.request.replace(/\.ngfactory$/, '');
            const nameStart = cleanedName.lastIndexOf('/') + 1;
            const name = cleanedName.substring(nameStart);
            return babelTarget.tagAssetsWithKey ? `${name}.${babelTarget.key}` : name;
        }
    }
    apply(compiler) {
        compiler.hooks.compilation.tap(PLUGIN_NAME, (compilation) => {
            if (compilation.name) {
                return;
            }
            compilation.hooks.beforeChunkIds.tap(PLUGIN_NAME, (chunks) => {
                chunks.forEach(chunk => {
                    if (chunk.id || chunk.name) {
                        return;
                    }
                    chunk.id = this.getNameFromOrigin(chunk);
                });
            });
        });
    }
}
exports.NamedLazyChunksPlugin = NamedLazyChunksPlugin;
//# sourceMappingURL=named.lazy.chunks.plugin.js.map